# BMP280 Temperature, Pressure, & Altitude Sensor

[![Build Status](https://img.shields.io/github/actions/workflow/status/pimoroni/bmp280-python/test.yml?branch=main)](https://github.com/pimoroni/bmp280-python/actions/workflows/test.yml)
[![Coverage Status](https://coveralls.io/repos/github/pimoroni/bmp280-python/badge.svg?branch=main)](https://coveralls.io/github/pimoroni/bmp280-python?branch=main)
[![PyPi Package](https://img.shields.io/pypi/v/bmp280.svg)](https://pypi.python.org/pypi/bmp280)
[![Python Versions](https://img.shields.io/pypi/pyversions/bmp280.svg)](https://pypi.python.org/pypi/bmp280)

Suitable for measuring ambient temperature, barometric pressure, and altitude, the BMP280 is a basic weather sensor.

# Installing

Stable library from PyPi:

* Just run `pip install bmp280`

Latest/development library from GitHub:

* `git clone https://github.com/pimoroni/bmp280-python`
* `cd bmp280-python`
* `./install.sh --unstable`

